// Copyright (c) 2023 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#include "PrefabParser.hpp"

using namespace Dawn;

std::vector<std::string> PrefabParser::getRequiredAttributes() {
  return { "name", "type" };
}

std::map<std::string, std::string> PrefabParser::getOptionalAttributes() {
  return { };
}

int32_t PrefabParser::onParse(
  Xml *node,
  std::map<std::string, std::string> values,
  struct Prefab *out,
  std::string *error
) {
  out->name = values["name"];
  out->type = values["type"];

  auto itChildren = node->children.begin();
  while(itChildren != node->children.end()) {
    // Parse child nodes, they may be components or not
    auto c = *itChildren;
    if(c->node == "child") {
      std::cout << "Child detected" << std::endl;
    } else {
      struct PrefabComponent component;
      component.registry = out->registry;
      auto ret = (PrefabComponentParser()).parse(*itChildren, &component, error);
      if(ret != 0) return ret;
      out->components.push_back(component);
    }
    ++itChildren;
  }

  return 0;
}